@@ -7,9 +7,14 @@ from typing import (
 import pytest
 
 from .assertion import SnapshotAssertion
+from .extensions import DEFAULT_EXTENSION
 from .location import TestLocation
-from .serializers import DEFAULT_SERIALIZER
 from .session import SnapshotSession
+from .terminal import (
+    green,
+    red,
+    reset,
+)
 
 
 def pytest_addoption(parser: Any) -> None:
@@ -25,6 +30,13 @@ def pytest_addoption(parser: Any) -> None:
         dest="update_snapshots",
         help="Update snapshots",
     )
+    group.addoption(
+        "--snapshot-warn-unused",
+        action="store_true",
+        default=False,
+        dest="warn_unused_snapshots",
+        help="Do not fail on unused snapshots",
+    )
 
 
 def pytest_assertrepr_compare(op: str, left: Any, right: Any) -> Optional[List[str]]:
@@ -33,10 +45,10 @@ def pytest_assertrepr_compare(op: str, left: Any, right: Any) -> Optional[List[s
     https://docs.pytest.org/en/latest/reference.html#_pytest.hookspec.pytest_assertrepr_compare
     """
     if isinstance(left, SnapshotAssertion):
-        assert_msg = f"snapshot {op} {right}"
+        assert_msg = reset(f"{green(left.name)} {op} {red('received')}")
         return [assert_msg] + left.get_assert_diff(right)
     elif isinstance(right, SnapshotAssertion):
-        assert_msg = f"{left} {op} snapshot"
+        assert_msg = reset(f"{red('received')} {op} {green(right.name)}")
         return [assert_msg] + right.get_assert_diff(left)
     return None
 
@@ -48,7 +60,9 @@ def pytest_sessionstart(session: Any) -> None:
     """
     config = session.config
     session._syrupy = SnapshotSession(
-        update_snapshots=config.option.update_snapshots, base_dir=config.rootdir
+        warn_unused_snapshots=config.option.warn_unused_snapshots,
+        update_snapshots=config.option.update_snapshots,
+        base_dir=config.rootdir,
     )
     session._syrupy.start()
 
@@ -69,22 +83,23 @@ def pytest_collection_finish(session: Any) -> None:
     session._syrupy._ran_items.update(session.items)
 
 
-def pytest_sessionfinish(session: Any) -> None:
+def pytest_sessionfinish(session: Any, exitstatus: int) -> None:
     """
     Add syrupy report to pytest after whole test run finished, before exiting.
     https://docs.pytest.org/en/latest/reference.html#_pytest.hookspec.pytest_sessionfinish
     """
     reporter = session.config.pluginmanager.get_plugin("terminalreporter")
-    session._syrupy.finish()
-    for line in session._syrupy.report:
+    syrupy_exitstatus = session._syrupy.finish()
+    for line in session._syrupy.report.lines:
         reporter.write_line(line)
+    session.exitstatus |= syrupy_exitstatus
 
 
 @pytest.fixture
 def snapshot(request: Any) -> "SnapshotAssertion":
     return SnapshotAssertion(
         update_snapshots=request.config.option.update_snapshots,
-        serializer_class=DEFAULT_SERIALIZER,
+        extension_class=DEFAULT_EXTENSION,
         test_location=TestLocation(request.node),
         session=request.session._syrupy,
     )
